# HWComponents-Library
HWComponents-Library contains a library of components from published works. It is
intended to be used to rapidly model prior works and to provide a common set of
components for comparison.

These models are for use with the HWComponents package, found at
https://accelergy-project.github.io/hwcomponents/.

## Installation

Install from PyPI:

```bash
pip install hwcomponents-library

# Check that the installation is successful
hwc --list | grep adder
```

## Contributing: Adding or Updating Numbers from Your Work
We would be happy to update these models given a pull request. Please see
"Creating Library Entries" and format your entries to match the existing
entries. If you have any questions, we would be happy to help.

Note that we will only accept entries that are published or backed by public
data. Citations are required for all entries.

## Citation

If you use this library in your work, please cite the following:

```bibtex
@misc{andrulis2024modelinganalogdigitalconverterenergyarea,
      title={Modeling Analog-Digital-Converter Energy and Area for Compute-In-Memory Accelerator Design},
      author={Tanner Andrulis and Ruicong Chen and Hae-Seung Lee and Joel S. Emer and Vivienne Sze},
      year={2024},
      eprint={2404.06553},
      archivePrefix={arXiv},
      primaryClass={cs.AR},
      url={https://arxiv.org/abs/2404.06553},
}
```
